@@ -48,7 +48,7 @@ class CodeBuild:
     def policies_create(self, policies):
         role_policies = list(self.iam.role_policies().keys())
         for base_name, policy in policies.items():
-            policy_name = "{0}-{1}".format(base_name, self.project_name)
+            policy_name = "{0}_{1}".format(base_name, self.project_name)
             if policy_name in role_policies:
                 continue
             if self.iam.policy_info(policy_name) is None:
